cd data

ncgen -o in.nc in.cdl || exit 1

ncks -H --trd -v one in.nc || exit 1

ncap2 -O -v -s "erf_one=float(gsl_sf_erf(1.0f));" in.nc foo.nc || exit 1
ncks -v erf_one foo.nc || exit 1




ncks --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
ncap2 --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
ncks -M "http://tds.marine.rutgers.edu/thredds/dodsC/roms/espresso/2013_da/his/ESPRESSO_Real-Time_v2_History_Best"
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
